import Flutter
import UIKit

public class SwiftDataDomeDioPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "datadome_dio", binaryMessenger: registrar.messenger())
    let instance = SwiftDataDomeDioPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    if (call.method == "storeCookie") {
        guard let args = call.arguments as? Dictionary<String, Any>,
              let body = args["cookie"] as? String else {
            print("[DataDome][Error] Did not receive a cookie to store")
            return
        }

        
        let splitString = body.split(separator: ";")
        var cookies: [String: String] = [:]
        for splitStr in splitString where splitStr.contains("=") {
            let param = splitStr.split(separator: "=")
            let key = String(param[0])
            let value = String(param[1])
            cookies[key.trimmingCharacters(in: .whitespacesAndNewlines)] = value
        }
        
        guard let datadomeCookieValue = cookies["datadome"] else {
            print("[DataDome][Error] Script message with empty datadome cookie received after resolving the captcha!")
            return
        }
        
        guard let actualCookie = HTTPCookieStorage.shared.cookies?.first(where: { $0.name == "datadome" }),
              let actualCookieParameters = actualCookie.properties else {
            print("[DataDome][Error] Cannot find local datadome cookie after resolving the captcha!")
            return
        }
        
        var newCookieParameters = actualCookieParameters
        newCookieParameters[HTTPCookiePropertyKey.value] = datadomeCookieValue
        
        guard let newCookie = HTTPCookie(properties: newCookieParameters) else {
            print("[DataDome][Error] Unable to create a new cookie after resolving the captcha!")
            return
        }
        
        HTTPCookieStorage.shared.setCookie(newCookie)
    }
  }
}
